@@ -1,4 +1,4 @@
-package Pcore::DBH::DDL::sqlite;    ## no critic qw[NamingConventions::Capitalization]
+package Pcore::DBH::DDL::sqlite;
 
 use Pcore -class;
 
