@@ -23,7 +23,7 @@ has busy_timeout => ( is => 'ro', isa => PositiveOrZeroInt, default => 1_000 * 3
 has temp_store   => ( is => 'ro', isa => Enum [qw[FILE MEMORY]],                            default => 'MEMORY' );
 has journal_mode => ( is => 'ro', isa => Enum [qw[DELETE TRUNCATE PERSIST MEMORY WAL OFF]], default => 'WAL' );      # WAL is the best
 has synchronous  => ( is => 'ro', isa => Enum [qw[FULL NORMAL OFF]],                        default => 'OFF' );      # OFF - data integrity on app failure, NORMAL - data integrity on app and OS failures, FULL - full data integrity on app or OS failures, slower
-has cache_size   => ( is => 'ro', isa => Int,  default => 20_000 );                                                  # 0+ - pages,  -kilobytes
+has cache_size   => ( is => 'ro', isa => Int,  default => -1_048_576 );                                              # 0+ - pages,  -kilobytes, default 1G
 has foreign_keys => ( is => 'ro', isa => Bool, default => 1 );
 
 sub BUILD ( $self, $args ) {
